<?php

use RedBeanPHP\R;

class User {

    protected $table;

    function __construct() {
        $settings = require __DIR__ . '/../settings.php';
        $this->table = $settings['settings']['db']['prefix'].'user';
    }

    public function doLogin($data) {
        $response = array();

        if ($data->username != "" && $data->password != "") {
            $user = $this->getUserByUsername($data->username);

            if (!is_null($user)) {
                $password = PassHash::check_password($user->password, $data->password);

                if ($password) {
                    $token = bin2hex(openssl_random_pseudo_bytes(16));
                    $response["uid"] = $user->id;
                    $response['token'] = $token;
                    $response["error"] = false;
                    $response["message"] = "You can login now.";
                    $user->token = $token;
                    $user->token_expire = '0000-00-00';
                    $user->updated_at = time();
                    $user->updated_by = "0";
                    R::store( $user );
                } else {
                    $response["error"] = true;
                    $response["message"] = "Wrong login.";
                }
            } else {
                $response["error"] = true;
                $response["message"] = "Missed parameters.";
            }

        } else {
            $response["error"] = true;
            $response["message"] = "Missed parameters.";
        }

        return $response;
    }

    public function doRegistration($data) {
        $response = array();

        if ($data->username != "" && $data->password != "") {
            if ($this->isUserSelected($data->username)) {
                $response["error"] = true;
                $response["message"] = "User exists.";
            } else {
                $password = PassHash::hash($data->password);

                $user = R::xdispense( $this->table );
                $user->username = $data->username;
                $user->password = $password;
                $user->token = "";
                $user->token_expire = '0000-00-00';
                $user->created_at = time();
                $user->created_by = "0";
                $user->updated_at = time();
                $user->updated_by = "0";
                R::store( $user );

                $response["error"] = false;
                $response["message"] = "You can login now.";
            }
        } else {
            $response["error"] = true;
            $response["message"] = "Missed parameters.";
        }

        return $response;
    }

    function isUserSelected($username) {
        $user = $this->getUserByUsername($username);

        return !is_null($user);
    }

    function getUserById($id) {
        $user  = R::load( $this->table, $id );

        return $user;
    }

    function getUserByUsername($username) {
        $user  = R::findOne( $this->table, ' username = ? ', [ $username ] );

        return $user;
    }
}
